@@ -251,11 +251,11 @@ def playlist_not_supported(name):
 
 def script_main(script_name, download, download_playlist=None):
 	if download_playlist:
-		help = 'python -m %s [--playlist] [-c|--create-dir] [--no-merge] url ...' % script_name
+		help = 'python -m youkudownloader [--playlist] [-c|--create-dir] [--no-merge] url ...'
 		short_opts = 'hc'
 		opts = ['help', 'playlist', 'create-dir', 'no-merge']
 	else:
-		help = 'python -m %s [--no-merge] url ...' % script_name
+		help = 'python -m youkudownloader [--no-merge] url ...'
 		short_opts = 'h'
 		opts = ['help', 'no-merge']
 	import sys, getopt
